starfish.operation package
==========================

Submodules
----------

.. toctree::

   starfish.operation.operation
   starfish.operation.operation_base
   starfish.operation.squid_operation

Module contents
---------------

.. automodule:: starfish.operation
   :members:
   :undoc-members:
   :show-inheritance:
